@@ -1,4 +1,4 @@
-# Copyright 2021 DeepL GmbH (https://www.deepl.com)
+# Copyright 2022 DeepL SE (https://www.deepl.com)
 # Use of this source code is governed by an MIT
 # license that can be found in the LICENSE file.
 
@@ -124,8 +124,9 @@ class HttpClient:
                 )
 
             log_info(
-                f"Starting retry {backoff.get_num_retries() + 1} for request {method} {url} "
-                f"after sleeping for {backoff.get_time_until_deadline():.2f} seconds."
+                f"Starting retry {backoff.get_num_retries() + 1} for request "
+                f"{method} {url} after sleeping for "
+                f"{backoff.get_time_until_deadline():.2f} seconds."
             )
             backoff.sleep_until_deadline()
 
