@@ -630,6 +630,35 @@ class Translator:
             request_data["glossary_id"] = glossary
         return request_data
 
+    def _create_glossary(
+        self,
+        name: str,
+        source_lang: Union[str, Language],
+        target_lang: Union[str, Language],
+        entries_format: str,
+        entries: str,
+    ) -> GlossaryInfo:
+        # glossaries are only supported for base language types
+        source_lang = Language.remove_regional_variant(source_lang)
+        target_lang = Language.remove_regional_variant(target_lang)
+
+        if not name:
+            raise ValueError("glossary name must not be empty")
+
+        request_data = {
+            "name": name,
+            "source_lang": source_lang,
+            "target_lang": target_lang,
+            "entries_format": entries_format,
+            "entries": entries,
+        }
+
+        status, content, json = self._api_call(
+            "v2/glossaries", data=request_data
+        )
+        self._raise_for_status(status, content, json, glossary=True)
+        return GlossaryInfo.from_json(json)
+
     def close(self):
         if hasattr(self, "_client"):
             self._client.close()
@@ -851,6 +880,7 @@ class Translator:
         target_lang: str,
         formality: Union[str, Formality] = Formality.DEFAULT,
         glossary: Union[str, GlossaryInfo, None] = None,
+        filename: Optional[str] = None,
     ) -> DocumentStatus:
         """Upload document, translate it into the target language, and download
         result.
@@ -868,6 +898,8 @@ class Translator:
             Formality enum, "less" or "more".
         :param glossary: (Optional) glossary or glossary ID to use for
             translation. Must match specified source_lang and target_lang.
+        :param filename: (Optional) Filename including extension, only required
+            if uploading string or bytes containing file content.
         :return: DocumentStatus when document translation completed, this
             allows the number of billed characters to be queried.
 
@@ -881,6 +913,7 @@ class Translator:
             source_lang=source_lang,
             formality=formality,
             glossary=glossary,
+            filename=filename,
         )
 
         try:
@@ -1129,28 +1162,59 @@ class Translator:
         :raises DeepLException: If source and target language pair are not
             supported for glossaries.
         """
-        # glossaries are only supported for base language types
-        target_lang = Language.remove_regional_variant(target_lang)
-        source_lang = Language.remove_regional_variant(source_lang)
-
-        if not name:
-            raise ValueError("glossary name must not be empty")
         if not entries:
             raise ValueError("glossary entries must not be empty")
 
-        request_data = {
-            "name": name,
-            "source_lang": source_lang,
-            "target_lang": target_lang,
-            "entries_format": "tsv",
-            "entries": util.convert_dict_to_tsv(entries),
-        }
-
-        status, content, json = self._api_call(
-            "v2/glossaries", data=request_data
+        return self._create_glossary(
+            name,
+            source_lang,
+            target_lang,
+            "tsv",
+            util.convert_dict_to_tsv(entries),
+        )
+
+    def create_glossary_from_csv(
+        self,
+        name: str,
+        source_lang: Union[str, Language],
+        target_lang: Union[str, Language],
+        csv_data: Union[TextIO, BinaryIO, str, bytes, Any],
+    ) -> GlossaryInfo:
+        """Creates a glossary with given name for the source and target
+        languages, containing the entries in the given CSV data.
+        The glossary may be used in the translate_text functions.
+
+        Only certain language pairs are supported. The available language pairs
+        can be queried using get_glossary_languages(). Glossaries are not
+        regional specific: a glossary with target language EN may be used to
+        translate texts into both EN-US and EN-GB.
+
+        This function allows you to upload a glossary CSV file that you have
+        downloaded from the DeepL website.
+
+        Information about the expected CSV format can be found in the API
+        documentation: https://www.deepl.com/docs-api/managing-glossaries/supported-glossary-formats/  # noqa
+
+        :param name: user-defined name to attach to glossary.
+        :param source_lang: Language of source terms.
+        :param target_lang: Language of target terms.
+        :param csv_data: CSV data containing glossary entries, either as a
+            file-like object or string or bytes containing file content.
+        :return: GlossaryInfo containing information about created glossary.
+
+        :raises ValueError: If the glossary name is empty, or entries are
+            empty or invalid.
+        :raises DeepLException: If source and target language pair are not
+            supported for glossaries.
+        """
+
+        entries = (
+            csv_data if isinstance(csv_data, (str, bytes)) else csv_data.read()
+        )
+
+        return self._create_glossary(
+            name, source_lang, target_lang, "csv", entries
         )
-        self._raise_for_status(status, content, json, glossary=True)
-        return GlossaryInfo.from_json(json)
 
     def get_glossary(self, glossary_id: str) -> GlossaryInfo:
         """Retrieves GlossaryInfo for the glossary with specified ID.
